#
# spec file for package openexr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define prjname      openexr
# perhaps you want to build against corresponding Imath build
%define debug_build 0
%define sonum 31
%global so_suffix -3_2
Name:           openexr
Version:        3.2.2
Release:        1.1
Summary:        Utilities for working with HDR images in OpenEXR format
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://www.openexr.com/
Source0:        https://github.com/openexr/openexr/archive/v%{version}.tar.gz
Source2:        baselibs.conf
BuildRequires:  cmake >= 3.12
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Imath)
BuildRequires:  pkgconfig(libdeflate)
BuildRequires:  pkgconfig(zlib)
Obsoletes:      OpenEXR <= 1.6.1
Provides:       OpenEXR = %{version}

%description
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications. This package
contains a set of utilities to work with this format.

* exrheader, a utility for dumping header information
* exrstdattr, a utility for modifying OpenEXR standard attributes
* exrmaketiled, for generating tiled and rip/mipmapped images
* exrenvmap, for creating OpenEXR environment maps
* exrmakepreview, for creating preview images for OpenEXR files
* exr2aces, converter to ACES format
* exrmultiview, combine two or more images into one multi-view

%package -n libIex%{so_suffix}-%{sonum}
Summary:        Exception handling library for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libIex%{so_suffix}-%{sonum}
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains shared library libIex

%package -n libIlmThread%{so_suffix}-%{sonum}
Summary:        Thread abstraction library for OpenEXR
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libIlmThread%{so_suffix}-%{sonum}
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains shared library libIlmThread

%package -n libOpenEXR%{so_suffix}-%{sonum}
Summary:        Library to Handle EXR Pictures in 16-Bit Floating-Point Format
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libOpenEXR%{so_suffix}-%{sonum}
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains shared library libOpenEXR

%package -n libOpenEXRCore%{so_suffix}-%{sonum}
Summary:        Library to Handle EXR Pictures in 16-Bit Floating-Point Format
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libOpenEXRCore%{so_suffix}-%{sonum}
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains shared library libOpenEXRCore

%package -n libOpenEXRUtil%{so_suffix}-%{sonum}
Summary:        Library to simplify development of OpenEXR utilities
License:        BSD-3-Clause
Group:          System/Libraries

%description -n libOpenEXRUtil%{so_suffix}-%{sonum}
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains shared library libOpenEXRUtil

%package devel
Summary:        Development files for the 16-bit FP EXR picture handling library
License:        BSD-3-Clause AND GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       Imath-devel
Requires:       libOpenEXR%{so_suffix}-%{sonum} = %{version}
Requires:       libOpenEXRCore%{so_suffix}-%{sonum} = %{version}
Requires:       libOpenEXRUtil%{so_suffix}-%{sonum} = %{version}
Requires:       pkgconfig
Requires:       pkgconfig(zlib)
Obsoletes:      OpenEXR-devel <= 1.6.1
Provides:       OpenEXR-devel = %{version}
Obsoletes:      libopenexr-devel <= 1.7.0
Provides:       libopenexr-devel = %{version}
Obsoletes:      ilmbase-devel < 3.0
Provides:       ilmbase-devel = %{version}

%description devel
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains header files.

%package doc
Summary:        Documentation for the 16-bit FP EXR picture handling library
License:        BSD-3-Clause
Group:          Documentation/Other
Obsoletes:      OpenEXR-doc <= 1.6.1
Provides:       OpenEXR-doc = %{version}
BuildArch:      noarch

%description doc
OpenEXR is a high dynamic-range (HDR) image file format developed by
Industrial Light & Magic for use in computer imaging applications.

This package contains documentation.

%prep
%autosetup -p1

%build
export PTHREAD_LIBS="-lpthread"
%if %{debug_build}
export CXXFLAGS="%{optflags} -O0"
%endif
%cmake \
  -DCMAKE_INSTALL_DOCDIR="%{_docdir}/%{name}"
%cmake_build

%install
%cmake_install

%check
# bin tests download test data from internet
EXCLUDE_REGEX='OpenEXR.bin'
%ifarch ppc64le
# bsc#1205885
EXCLUDE_REGEX="$EXCLUDE_REGEX|testMultiTiledPartThreading"
%endif
%ifarch aarch64
# https://github.com/AcademySoftwareFoundation/openexr/issues/1460
EXCLUDE_REGEX="$EXCLUDE_REGEX|DWA[AB]Compression"
%endif
# test failure on LE: https://github.com/AcademySoftwareFoundation/openexr/issues/1460
%ifnarch i586 ppc ppc64 s390 s390x
export LD_LIBRARY_PATH="%{buildroot}/%{_libdir}"
# tests can take longer than the default timeout of 25 minutes
%if 0%{?suse_version} < 1550
# HACK - older versions of the ctest macro do not allow passing additional parameters
%global __ctest %{__ctest} --timeout 3600
%endif
%ctest --exclude-regex "$EXCLUDE_REGEX" --timeout 3600
%endif

%post -n libIex%{so_suffix}-%{sonum} -p /sbin/ldconfig
%postun -n libIex%{so_suffix}-%{sonum} -p /sbin/ldconfig
%post -n libIlmThread%{so_suffix}-%{sonum} -p /sbin/ldconfig
%postun -n libIlmThread%{so_suffix}-%{sonum} -p /sbin/ldconfig
%post -n libOpenEXR%{so_suffix}-%{sonum} -p /sbin/ldconfig
%postun -n libOpenEXR%{so_suffix}-%{sonum} -p /sbin/ldconfig
%post -n libOpenEXRCore%{so_suffix}-%{sonum} -p /sbin/ldconfig
%postun -n libOpenEXRCore%{so_suffix}-%{sonum} -p /sbin/ldconfig
%post -n libOpenEXRUtil%{so_suffix}-%{sonum} -p /sbin/ldconfig
%postun -n libOpenEXRUtil%{so_suffix}-%{sonum} -p /sbin/ldconfig

%files
%license LICENSE.md
%doc CHANGES.md CODE_OF_CONDUCT.md CODEOWNERS CONTRIBUTING.md CONTRIBUTORS.md README.md SECURITY.md
%{_bindir}/exrenvmap
%{_bindir}/exrheader
%{_bindir}/exrinfo
%{_bindir}/exrmakepreview
%{_bindir}/exrmaketiled
%{_bindir}/exrstdattr
%{_bindir}/exrmultiview
%{_bindir}/exrmultipart
%{_bindir}/exr2aces

%files devel
%{_includedir}/OpenEXR
%{_libdir}/libIex.so
%{_libdir}/libIex%{so_suffix}.so
%{_libdir}/libIlmThread.so
%{_libdir}/libIlmThread%{so_suffix}.so
%{_libdir}/libOpenEXR.so
%{_libdir}/libOpenEXR%{so_suffix}.so
%{_libdir}/libOpenEXRCore.so
%{_libdir}/libOpenEXRCore%{so_suffix}.so
%{_libdir}/libOpenEXRUtil.so
%{_libdir}/libOpenEXRUtil%{so_suffix}.so
%{_libdir}/pkgconfig/OpenEXR.pc
%dir %{_libdir}/cmake/OpenEXR
%{_libdir}/cmake/OpenEXR/*.cmake

%files doc
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/{CHANGES.md,CODE_OF_CONDUCT.md,CODEOWNERS,CONTRIBUTING.md,CONTRIBUTORS.md,README.md,SECURITY.md}

%files -n libIex%{so_suffix}-%{sonum}
%license LICENSE.md
%{_libdir}/libIex-*.so.*

%files -n libIlmThread%{so_suffix}-%{sonum}
%license LICENSE.md
%{_libdir}/libIlmThread-*.so.*

%files -n libOpenEXR%{so_suffix}-%{sonum}
%license LICENSE.md
%{_libdir}/libOpenEXR-*.so.*

%files -n libOpenEXRCore%{so_suffix}-%{sonum}
%license LICENSE.md
%{_libdir}/libOpenEXRCore-*.so.*

%files -n libOpenEXRUtil%{so_suffix}-%{sonum}
%license LICENSE.md
%{_libdir}/libOpenEXRUtil-*.so.*

%changelog
* Wed Feb 14 2024 pgajdos@suse.com
- version update to 3.2.2 [bsc#1219498]
  * [CVE-2023-5841](https://takeonme.org/cves/CVE-2023-5841.html).
    Note that this bug is present in the C++ API (since v3.1.0), although
    it is in a routine that is predominantly used for development and
    testing. It is not likely to appear in production code.
  * OSS-fuzz [66491](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=66491)
    Out-of-memory in openexr_exrcorecheck_fuzzer
  * OSS-fuzz [66489](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=66489)
    Null-dereference in `Imf_3_3::realloc_deepdata`
- deleted patches
  - openexr-CVE-2023-5841.patch (upstreamed)
* Wed Feb  7 2024 pgajdos@suse.com
- version update to 3.2.1
  [#]# Version 3.2.0 (August 30, 2023)
  * Zip compression via ``libdeflate``
  * New camdkit/camdkit-enabled standard attributes
  * Updated SO versioning policy
  * Python bindings & PyPI wheel
  * Miscellaneous improvements
  [#]# Version 3.2.1 (September 27, 2023)
  * Fix for linking statically against an external ``libdeflate``
  * Fix a compile error with ``OPENEXR_VERSION_HEX``
  * Fix various compiler warnings
  * Pkg-config generation is now on by default for all systems, including Windows
- modified sources
  %% baselibs.conf
- added patches
  fix CVE-2023-5841 [bsc#1219498], heap-based buffer overflow in generic_unpack_deep()
  + openexr-CVE-2023-5841.patch
* Thu Aug 24 2023 pgajdos@suse.com
- version update to 3.1.11
  [#]# Version 3.1.11 (August 13, 2023)
  Patch release that fixes a build failure with `-march=x86-64-v3`
  * Initialize `regs[]` to 0 in `check_for_x86_simd`
  * Fix CPUID detection with `-march=x86-64-v3`
  [#]# Version 3.1.10 (August 2, 2023)
  Patch release that addresses miscellaneous build issues, test
  failures, and performance regressions, as well as:
  * OSS-fuzz [59457](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=59457)
  Heap-buffer-overflow in `LossyDctDecoder_execute`
  * Readdress #1456: disallow NaNs in `testOptimizedInterleavePatterns`
  * Revert pre-computed values
  * Fix handling for corrupt number of DC components
  * Add `OPENEXR_MISSING_ARM_VLD1` workaround to `internal_dwa_simd.h`
  * Fix Huffman performance regression on Linux/clang
  * Fix range check in dwa compressor
  * Fix build with i386 and musl libc
  * Fix the code contains unhandled character
  * Fix cpu detection of sse2 on non-64 x86
  * Fix the code contains unhandled character
  * Fix gcc-11 warnings: signed/unsigned integer comparison, unused variables
  * Fix macOS and Windows build failures when threading is disabled
  * Fix build error on win_arm64
- deleted patches
  - 1488.patch (upstreamed)
* Tue Jul 18 2023 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix regression on non-SSE architectures
  https://github.com/AcademySoftwareFoundation/openexr/issues/1460:
  * 1488.patch
- Also disable 'DWA[AB]Compression' test on aarch64 as the patch
  above fixes the issue for all targets, except aarch64
* Tue Jun 27 2023 pgajdos@suse.com
- version update to 3.1.9
  * Patch release that addresses miscelleneous build and doc issues, as well as:
    . OSS-fuzz 59382 Heap-buffer-overflow in internal_huf_decompress
* Tue Jun 20 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.8:
  * Support for DWA compression in OpenEXRCore
  * Fix OSS-fuzz 59070 Stack-buffer-overflow in
    DwaCompressor_readChannelRules
* Sat Apr 15 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.7:
  * Patch release that fixes a build regression on ARMv7, and
    fixes a build issue with zlib.
* Tue Mar 14 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 3.1.6:
  * NEON optimizations for ZIP reading
  * Enable fast Huffman & Huffman zig-zag transform for Arm Neon
  * Support relative and absolute libdir/includedir in pkg-config generation
  * Fix for reading memory mapped files with DWA compression
  * Enable SSE4 support on Windows
  * Fast huf decoder
- Drop gcc13-fix.patch
* Mon Mar  6 2023 Martin Liška <mliska@suse.cz>
- Add upstream fix gcc13-fix.patch.
* Mon Feb 27 2023 pgajdos@suse.com
- fltk not needed (openexr-3.1.5/ASWF/tsc-meetings/2021-01-14.md)
* Thu Dec  8 2022 pgajdos@suse.com
- skip testMultiTiledPartThreading for ppc64le [bsc#1205885]
* Sat Nov  5 2022 Hans-Peter Jansen <hpj@urpla.net>
- Add _constraints: 6000 MiB memory
* Mon May  2 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.5:
  * Add backwards-compatibilty flags to the core library to match
    original behavior of the the c++ library. Fixes reading of certain
    files by the new core.
  * Fix build failures on MSVC14 and MSVC 2022
  * Fix build failure on latest 64-bit Ubuntu
  * Documentation refers to primary branch as "main"
  * Update the CI workflow matrix to VFX-CY2022
  * Update auto-fetch Imath version to v3.1.5
  Specific OSS-fuzz issues:
  * OSS-fuzz [46309](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=46309)
  Heap-buffer-overflow in Imf_3_1::memstream_read
  * OSS-fuzz [46083](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=46083)
  Out-of-memory in openexr_exrcheck_fuzzer
  * OSS-fuzz [45899](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=45899)
  Integer-overflow in internal_exr_compute_chunk_offset_size
  * OSS-fuzz [44084](https://bugs.chromium.org/p/oss-fuzz/issues/detail?id=44084)
  Out-of-memory in openexr_exrcheck_fuzzer
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 3.1.4 (bsc#1194333):
  * Several bug fixes to properly reject invalid input upon read
  * A check to enable SSE2 when building with Visual Studio
  * A check to fix building with VisualStudio on ARM64
  * Update the automatically-downloaded version of Imath to v3.1.4
  * Miscellaneous documentation improvements
- drop openexr-CVE-2021-45942.patch (upstream)
* Wed Jan  5 2022 pgajdos@suse.com
- security update
- added patches
  fix CVE-2021-45942 [bsc#1194333], heap-based buffer overflow in Imf_3_1:LineCompositeTask:execute
  + openexr-CVE-2021-45942.patch
* Tue Nov  9 2021 pgajdos@suse.com
- version update to 3.1.3
  Patch release with a change to default zip compression level:
  * Default zip compression level is now 4 (instead of 6), which in our
    tests improves compression times by 2x with only a tiny drop in
    compression ratio.
  * ``setDefaultZipCompression()`` and ``setDefaultDwaCompression()``
    now set default compression levels for writing.
  * The Header how has ``zipCompressionLevel()`` and
    ``dwaCompressionLevel()`` to return the levels used for writing.
  Also, various bug fixes, build improvements, and documentation
  updates. In particular:
  * Fixes a build failure with Imath prior to v3.1
  * Fixes a bug in detecting invalid chromaticity values
- deleted patches
  - openexr-fix-armv7-2.patch (upstreamed)
  - openexr-fix-armv7.patch (upstreamed)
* Tue Aug 31 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patch to fix OpenEXRCore.testHUF on armv7:
  * openexr-fix-armv7.patch
  * openexr-fix-armv7-2.patch
* Mon Aug 16 2021 pgajdos@suse.com
- devel package obsoletes and provides ilmbase-devel
* Fri Aug 13 2021 pgajdos@suse.com
- run spec-cleaner
* Fri Aug 13 2021 pgajdos@suse.com
- fix baselibs.conf
- modified sources
  %% baselibs.conf
* Fri Aug 13 2021 pgajdos@suse.com
- version update to 3.1.1
  3.1.1
  * Patch release that fixes build failures on various systems,
    introduces CMake CMAKE_CROSSCOMPILING_EMULATOR support, and
    fixes a few other minor issues.
  3.1
  * The 3.1 release of OpenEXR introduces a new library, OpenEXRCore,
    which is the result of a significant re-thinking of how OpenEXR
    manages file I/O and provides access to image data. It begins
    to address long-standing scalability issues with multithreaded
    image reading and writing.
  3.0.1
  Major release with major build restructing, security improvements, and
  new features:
  * Restructuring:
  - The IlmBase/PyIlmBase submodules have been separated into the
    Imath project, now included by OpenEXR via a CMake submodule
    dependency, fetched automatically via CMake's FetchContent if
    necessary.
  - The library is now called ``libOpenEXR`` (instead of
    ``libIlmImf``).  No header files have been renamed, they retain
    the ``Imf`` prefix.
  - Symbol linkage visibility is limited to specific public symbols.
  * Build improvements:
  - No more simultaneous static/shared build option.
  - Community-provided support for bazel.
  * New Features:
  - ID Manifest Attributes, as described in ["A Scheme for Storing
    Object ID Manifests in OpenEXR
    Images"](https://doi.org/10.1145/3233085.3233086), Peter Hillman,
    DigiPro 18: Proceedings of the 8th Annual Digital Production
    Symposium, August 2018.
  - New program: exrcheck validates the contents of an EXR file.
  * Changes:
  - EXR files with no channels are no longer allowed.
  - Hard limit on the size of deep tile sizes; tiles must be less than
    2^30 pixels.
  - Tiled DWAB files used STATIC_HUFFMAN compression.
  - ``Int64`` and ``SInt64`` types are deprecated in favor of
    ``uint64_t`` and ``int64_t``.
  - Header files have been pruned of extraneous ``#include``'s
    ("Include What You Use"), which may generate compiler errors in
    application source code from undefined symbols or
    partially-defined types. These can be resolved by identifying and
    including the appropriate header.
  - See the [porting
    guide](https://github.com/AcademySoftwareFoundation/Imath/blob/master/docs/PortingGuide2-3.md)
    for details about differences from previous releases and how to
    address them.
  - Also refer to the porting guide for details about changes to
    Imath
- deleted patches
  - 0001-Use-absolute-CMAKE_INSTALL_FULL_LIBDIR-for-libdir-in.patch, renamed:
- added patches
  fix https://github.com/AcademySoftwareFoundation/openexr/issues/595
  + openexr-pkgconfig-fix-libdir.patch
- deleted sources
  - _multibuild (not needed)
- see CHANGES.md for details
- deleted patches
  - openexr-pkgconfig-fix-libdir.patch (upstreamed)
* Tue Aug  3 2021 pgajdos@suse.com
- version update to 2.5.7
  Patch release of 2.5 with security and build fixes:
  * OSS-fuzz 28051 Heap-buffer-overflow in Imf_2_5::copyIntoFrameBuffer
  * OSS-fuzz 28155 Crash in Imf_2_5::PtrIStream::read
  * Fix broken symlink and pkg-config lib suffix for cmake debug builds
- modified patches
  %% 0001-Use-absolute-CMAKE_INSTALL_FULL_LIBDIR-for-libdir-in.patch (refreshed)
- deleted patches
  - openexr-CVE-2021-3598.patch (upstreamed)
  - openexr-CVE-2021-3605.patch (upstreamed)
* Wed Jun 16 2021 pgajdos@suse.com
- security update
- added patches
  fix CVE-2021-3605 [bsc#1187395], Heap buffer overflow in the rleUncompress function
  + openexr-CVE-2021-3605.patch
* Tue Jun 15 2021 pgajdos@suse.com
- security update
- added patches
  fix CVE-2021-3598 [bsc#1187310], Heap buffer overflow in Imf_3_1:CharPtrIO:readChars
  + openexr-CVE-2021-3598.patch
* Tue Jun 15 2021 pgajdos@suse.com
- version update to 2.5.6
  * [#1013](https://github.com/AcademySoftwareFoundation/openexr/pull/1013)
  Fixed regression in Imath::succf() and Imath::predf() when negative values are given
* Wed Mar 31 2021 pgajdos@suse.com
- version update to 2.5.5
  Patch release with various bug/sanitizer/security fixes, primarily
  related to reading corrupted input files, but also a fix for universal
  build support on macOS.
- see CHANGES.md for details
* Thu Jan  7 2021 pgajdos@suse.com
- merge also baselibs.conf
- modified sources
  %% baselibs.conf
* Tue Jan  5 2021 pgajdos@suse.com
- merge ilmbase and openexr source packages into one _multibuild
- added sources
  + _multibuild
* Tue Jan  5 2021 pgajdos@suse.com
- version update to 2.5.4
  * Patch release with various bug/sanitizer/security fixes, primarily
    related to reading corrupted input files.
* Wed Sep 30 2020 pgajdos@suse.com
- version update to 2.5.3
  * Various sanitizer/fuzz-identified issues related to handling of invalid input
  * Fixes to misc compiler warnings
  * Cmake fix for building on arm64 macOS (#772)
  * Read performance optimization (#782)
  * Fix for building on non-glibc (#798)
  * Fixes to tests
* Tue Sep 15 2020 ro@suse.de
- Disable testsuite also on s390/s390x, probably will not pass
  on any bigendian platform in current state
* Thu Jul 16 2020 Andreas Schwab <schwab@suse.de>
- Disable testsuite also on ppc
* Sun Jul  5 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix 0001-Use-absolute-CMAKE_INSTALL_FULL_LIBDIR-for-libdir-in.patch
  so pkgconfig file has no duplicate prefix.
- Run test suite also on all other archs but i586 and ppc64(be)
* Mon Jun 29 2020 pgajdos@suse.com
- version update to 2.5.2
  2.5.2
  * Invalid input could cause a heap-use-after-free error in DeepScanLineInputFile::DeepScanLineInputFile()
  * Invalid chunkCount attributes could cause heap buffer overflow in getChunkOffsetTableSize()
  * Invalid tiled input file could cause invalid memory access TiledInputFile::TiledInputFile()
  * OpenEXRConfig.h now correctly sets OPENEXR_PACKAGE_STRING to "OpenEXR" (rather than "IlmBase")
  2.5.1
  * A patch release that corrects the SO version for the v2.5 release,
    which missed getting bumped in v2.5.0.
  * This release also fixes an improper failure in IlmImfTest when running
    on ARMv7 and AAarch64.
  2.5.0
  * No more build-time header generation: toFloat.h, eLut.h,
    b44ExpLogTable.h, and dwaLookups.h are now ordinary header files, no
    longer generated on the fly.
  * New StdISSTream class, an "input" stringstream version of StdOSStream
  * New Matrix22 class in Imath
  * Chromaticity comparison operator now includes white (formerly ignored)
  * Various cmake fixes
  * Bug fixes for various memory leaks
  * Bug fixes for various invalid memory accesses
  * New checks to detect damaged input files
  * OpenEXR_Viewers has been deprecated, removed from the top-level
    cmake build and documentation.
- modified patches
  %% 0001-Use-absolute-CMAKE_INSTALL_FULL_LIBDIR-for-libdir-in.patch (refreshed)
- modified sources
  %% baselibs.conf
* Thu Apr 16 2020 pgajdos@suse.com
- version update to 2.4.1
  * Various fixes for memory leaks and invalid memory accesses
  * Various fixes for integer overflow with large images.
  * Various cmake fixes for build/install of python modules.
  * ImfMisc.h is no longer installed, since it's a private header.
- deleted patches
  - Fix-the-symlinks-creation.patch (upstreamed)
* Mon Feb 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix relative paths in generated pkgconfig files:
  0001-Use-absolute-CMAKE_INSTALL_FULL_LIBDIR-for-libdir-in.patch
* Sun Nov 24 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with older cmake package (Leap 15.0 up to 15.2), the
  included ctest macro does not accept extra parameters.
* Thu Nov 14 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-the-symlinks-creation.patch to fix the symlinks creation.
* Mon Oct  7 2019 pgajdos@suse.com
- fix OpenEXR.pc
* Fri Oct  4 2019 pgajdos@suse.com
- increase timeout for IlmImf test
* Thu Sep 26 2019 pgajdos@suse.com
- version update to 2.4.0
  * Completely re-written CMake configuration files
  * Improved support for building on Windows, via CMake
  * Improved support for building on macOS, via CMake
  * All code compiles without warnings on gcc, clang, msvc
  * Cleanup of license and copyright notices
  * floating-point exception handling is disabled by default
  * New Slice::Make method to reliably compute base pointer for a slice.
  * Miscellaneous bug fixes
  * CVE-2018-18444 Issue #351 Out of Memory
  * CVE-2018-18443 Issue #350 heap-buffer-overflow
- upstream does not provide gpg signature anymore
  https://github.com/openexr/openexr/issues/565
- modified sources
  %% baselibs.conf
- deleted patches
  - openexr-CVE-2017-14988.patch (upstreamed)
  - openexr-CVE-2017-9111,9113,9115.patch (upstreamed)
  - openexr-CVE-2018-18444.patch (upstreamed)
- deleted sources
  - openexr-2.3.0.tar.gz.sig (not needed)
  - openexr.keyring (not needed)
* Fri Sep 20 2019 pgajdos@suse.com
- testsuite only for x86_64 [bsc#1146648]
* Wed Aug 21 2019 Martin Pluskal <mpluskal@suse.com>
- Enable tests on architectures with enough memory - boo#1146648
  * disable imffuzztest as it takes to much resources
* Mon Jul 15 2019 pgajdos@suse.com
- security update
- added patches
  CVE-2017-14988 [bsc#1061305]
  + openexr-CVE-2017-14988.patch
* Fri Jun 14 2019 pgajdos@suse.com
- security update
- added patches
  CVE-2017-9111 [bsc#1040109], CVE-2017-9113 [bsc#1040113], CVE-2017-9115 [bsc#1040115]
  + openexr-CVE-2017-9111,9113,9115.patch
* Wed Nov  7 2018 Jan Engelhardt <jengelh@inai.de>
- Codify new ilmbase requirements.
* Wed Nov  7 2018 Petr Gajdos <pgajdos@suse.com>
- security update
  * CVE-2018-18444 [bsc#1113455]
    + openexr-CVE-2018-18444.patch
* Tue Nov  6 2018 Petr Gajdos <pgajdos@suse.com>
- asan_build: build ASAN included
- debug_build: build more suitable for debugging
* Mon Nov  5 2018 Jan Engelhardt <jengelh@inai.de>
- Remove useless --with-pic.
- Adjust RPM groups and repair sentence structure.
* Mon Nov  5 2018 Petr Gajdos <pgajdos@suse.com>
- updated to 2.3.0
  * ThreadPool overhead improvements, enable custom thread pool
    to be registered via ThreadPoolProvider class
  * Fixes to enable custom namespaces for Iex, Imf
  * Improve read performance for deep/zipped data, and
    SIMD-accelerated uncompress support
  * Added rawPixelDataToBuffer() function for access to
    compressed scanlines
  * Iex::BaseExc no longer derived from std::string.
  * Imath throw() specifiers removed
  * Initial Support for Python 3
  * removed patch
* Mon Jan 15 2018 avindra@opensuse.org
- Update to 2.2.1
  * Fix reported OpenEXR security vulnerabilities: CVE-2017-9110,
    CVE-2017-9111, CVE-2017-9112, CVE-2017-9113, CVE-2017-9114,
    CVE-2017-9115 and CVE-2017-9116
- pgajdos@suse.com: but really seem to fix only:
  CVE-2017-9110 [bsc#1040107], CVE-2017-9114 [bsc#1040114],
  CVE-2017-9116 [bsc#1040116], CVE-2017-12596 [bsc#1052522]; for
  the rest of issues see [bsc#1040109], [bsc#1040112],
  [bsc#1040113], [bsc#1040114], [bsc#1040115], and [bsc#1061305]
* Wed Jul 12 2017 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
* Thu Jan 29 2015 mlin@suse.com
- Update to 2.2.0
  * DreamWorks Lossy Compression A new high quality, high performance lossy
    compression codec contributed by DreamWorks Animation. This codec allows
    control over variable lossiness to balance visual quality and file size.
    This contribution also includes performance improvements that speed up
    the PIZ codec.
  * IlmImfUtil A new library intended to aid in development of image file
    manipulation utilities that support the many types of OpenEXR images.
  * This release also includes improvements to cross-platform build support
    using CMake.
- Bumped the soname, and now we have libIlmImf and libIlmImfUtil
- Removed openexr-2.1.0-headers.patch
- Updated openexr.keyring from the savannah project page.
* Tue Aug 26 2014 fcrozat@suse.com
- Add obsoletes to baselibs.conf.
* Thu Apr 24 2014 dmueller@suse.com
- remove dependency on gpg-offline (blocks rebuilds and
  tarball integrity is checked by source-validator anyway)
* Thu Nov 28 2013 toganm@opensuse.org
- add openexr-2.1.0-headers.patch to install
  ImfDeepImageStateAttribute.h header too
* Wed Nov 27 2013 mvyskocil@suse.com
- update to 2.1.0
  This release includes a refactoring of the optimised read paths for RGBA
  data, optimisations for some of the python bindings to Imath, improvements to
  the cmake build environment as well as additional documentation describing
  deep data in more detail.
- make tests conditional, enable fuzz test and huge test
* Mon Jul 15 2013 mvyskocil@suse.com
- update to 2.0.1
  This is a maintenance push that predominantly addresses edge case
  failures in the optimisation code paths by temporarily disabling the
  feature. For more details, please refer to the
  /usr/share/doc/packages/openexr/ChangeLog
- add gpg-offline based verification
* Sat Apr 20 2013 coolo@suse.com
- fix library deps
* Fri Apr 12 2013 mvyskocil@suse.com
- update to 2.0.0
  * Deep Data support - Pixels can now store a variable-length list of samples.
  The main rationale behind deep images is to enable the storage of multiple
  values at different depths for each pixel. OpenEXR 2.0 supports both
  hard-surface and volumetric representations for Deep Compositing workflows.
  * Multi-part Image Files - With OpenEXR 2.0, files can now contain a number
  of separate, but related, data parts in one file. Access to any part is
  independent of the others, pixels from parts that are not required in the
  current operation don't need to be accessed, resulting in quicker read
  times when accessing only a subset of channels. The multipart interface
  also incorporates support for Stereo images where views are stored in
  separate parts. This makes stereo OpenEXR 2.0 files significantly faster to
  work with than the previous multiview support in OpenEXR.
  * Optimized pixel reading - decoding RGB(A) scanline images has been
  accelerated on SSE processors providing a significant speedup when reading
  both old and new format images, including multipart and multiview files.
  * Namespacing - The library introduces versioned namespaces to avoid
  conflicts between packages compiled with different versions of the library.
- obsoleted
    openexr-suse-docdir.patch (moved in install phase)
    openexr-disable-tests.patch
* Thu Sep 27 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  No GPL licensed files found in the package
* Thu Sep 27 2012 idonmez@suse.com
- Update baselibs.conf
* Thu Aug  2 2012 mvyskocil@suse.cz
- Update to 1.7.1
  * Updated the .so verison to 7.
  * obsoletes openexr-includes.patch
- require new ilmbase-devel for build
- rename libopenexr-devel to openexr devel to be compatible
  with renamed ilmbase package
* Tue Apr 24 2012 mvyskocil@suse.cz
- disable the test at all, as running them in OBS seems not to be
  reliable
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
* Mon Oct 31 2011 mvyskocil@suse.cz
- openexr-disable-tests.patch - disable broken tests prevents a build
  in Factory
* Wed Jul 27 2011 dmueller@suse.de
- remove explicit libdrm buildrequires
* Tue Mar  8 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel build
* Mon Aug  9 2010 mvyskocil@suse.cz
- Update to 1.7.0 - bugfix release, multiviewer support
  * obsoletes CVE-2009-1720 support
  * built with --enable-larget-stack and test
- Renammed to be more comfortable with Shared Library policy
  * openexr - main (source package) contains tools in bindir, it provides and
    obsoletes the old OpenEXR symbol
  * libIlmImf6 - contains the openexr library
  * libopenexr-devel - contains the headers, Provides and Obsoletes the
    OpenEXR-devel symbol
  * openexr-doc - documentation
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Aug  4 2009 mvyskocil@suse.cz
- fixed bnc#527539:  VUL-0: OpenEXR: [ MDVSA-2009:190 ] OpenEXR
  used patches from Mandriva
  * CVE-2009-1720
  * CVE-2009-1721
* Mon Mar  2 2009 crrodriguez@suse.de
- save 6.7MB by removing static libraries and "la" files
* Wed Dec 10 2008 olh@suse.de
- use Obsoletes: -XXbit only for ppc64 to help solver during distupgrade
  (bnc#437293)
* Thu Oct 30 2008 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Oct 31 2007 mvyskocil@suse.cz
- update to 1.6.1
- fix buid, add docu subpackage with documentation and examples
* Sat May 19 2007 stbinner@suse.de
- fix linking of new IlmThread lib versus libpthread
* Mon May 14 2007 ltinkl@suse.cz
- update to 1.4.6
- fix build, fix packaging examples and doc
- added missing Requires
* Tue Jan 16 2007 meissner@suse.de
- fixed RPM_OPT_FLAGS
* Mon Jun 12 2006 dmueller@suse.de
- fix shared lib dependencies
- fix installed headers
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov  7 2005 sndirsch@suse.de
- make use of mesa-devel-packages macro in neededforbuild
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Wed May 25 2005 adrian@suse.de
- update to version 1.2.2
* Mon May 23 2005 schwab@suse.de
- Fix missing declaration.
* Thu Jan 13 2005 ro@suse.de
- try to fix docu installation
* Mon Jun 28 2004 adrian@suse.de
- initial package of version 1.2.1
